==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/addins/AspNet/MonoDevelop.AspNet/MonoDevelop.AspNet.Parser/AspNetParsedDocument.cs <==
// 
// AspNetCompilationUnit.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

using MonoDevelop.Projects.Dom;

namespace MonoDevelop.AspNet.Parser
{
	
	
	public class AspNetParsedDocument : ParsedDocument
	{
		public AspNetParsedDocument (string fileName) : base (fileName)
		{
			Flags |= ParsedDocumentFlags.NonSerializable;
			Type = AspNetAppProject.DetermineWebSubtype (fileName);
		}
		
		public PageInfo PageInfo { get; set; }
		public Document Document { get; set; }
		public WebSubtype Type { get; set; }
		
		public override IEnumerable<FoldingRegion> GenerateFolds ()
		{
			if (Document != null) {
				List<FoldingRegion> regions = new List<FoldingRegion> ();
				CompilationUnitVisitor cuVisitor = new CompilationUnitVisitor (regions);
				Document.RootNode.AcceptVisit (cuVisitor);
				return regions;
			}
			return new FoldingRegion [0];
		}
	}
}

==> monodevelop_2.4+dfsg.orig.tar.gz: monodevelop-2.4/src/addins/AspNet/MonoDevelop.AspNet/MonoDevelop.AspNet.Parser/AspNetParsedDocument.cs <==
// 
// AspNetCompilationUnit.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

using MonoDevelop.Projects.Dom;
using MonoDevelop.AspNet.Parser.Dom;

namespace MonoDevelop.AspNet.Parser
{
	
	
	public class AspNetParsedDocument : ParsedDocument
	{
		
		public AspNetParsedDocument (string fileName, WebSubtype type, RootNode rootNode, PageInfo info) : base (fileName)
		{
			Flags |= ParsedDocumentFlags.NonSerializable;
			Info = info;
			RootNode = rootNode;
			Type = type;
		}
		
		public PageInfo Info { get; private set; }
		public RootNode RootNode { get; private set; }
		public WebSubtype Type { get; private set; }
		
		public override IEnumerable<FoldingRegion> GenerateFolds ()
		{
			if (RootNode != null) {
				var regions = new List<FoldingRegion> ();
				var cuVisitor = new CompilationUnitVisitor (regions);
				RootNode.AcceptVisit (cuVisitor);
				return regions;
			}
			return new FoldingRegion [0];
		}
	}
}
